export default abstract class ActionInvoker {
    /**
     * Sends shortcut to txhe application. Some apps need to have focus so they can recieve shortcuts.
     *
     * @param shortcut key identifiers separated by space
     * @param applicationPath absolute path pointing to the app which should recieve shortcut
     * @param applicationPath required for BTT to recognize the app, whithin browser env must be provided manually
     */
    abstract sendShortcut: any;
    /**
     * Executes passed nodejs script. Requires manual specificying of node executable binary if used on frontend
     *
     * @param code a code to run
     */
    abstract executeScript: any;
    /**
     * Toggles do not disturb mode
     */
    abstract toggleDnD: any;
    /**
     * Toggles do not disturb mode
     */
    abstract toggleTrueTone: any;
    /**
     * Toggles night shift
     */
    abstract toggleNightShift: any;
    /**
     * Triggers system wide keyboard shortcut
     * @param shortcut key identifiers separated by space
     */
    abstract triggerShortcut: any;
    /**
     * Shows HUD with given config
     */
    abstract showHUD: any;
    /**
     * Sends / Types / Inserts / Pastes custom text
     */
    abstract sendText: any;
    /**
     * Triggers a haptic response. Takes a number as a param due to BTT lack of information
     * which ID represents which mode, in order to know what value represents what open BTT and map
     * the order of selects options in config of "Perform Haptic Feedback on Trackpad" action
     *
     * @param hapticMode a number representing each mode.
     */
    abstract hapticFeedback: any;
    /**
     * Open an application on the given path
     */
    abstract launchApplication: any;
    /**
     * Toggles the visibility of given application
     */
    abstract toggleApplication: any;
    /**
     * Toggles the mute state in the system
     */
    abstract mute: any;
    /**
     * Starts Siri
     */
    abstract startSiri: any;
    /**
     * Toggles the BetterTouchTool gesture recognition
     */
    abstract toggle: any;
    /**
     * Delays the next action. For most cases manually managing the execution of actions in JavaScript
     * should be sufficient - using this will block any new action that BTT will recieve
     *
     * @param timeout - time in miliseconds during any action execution will be delayed
     */
    abstract delayNextAction: any;
    /**
     * Moves mouse to specified position
     */
    abstract moveMouse: any;
    /**
     * Toggles the mouse speed between a regular and speeded up one
     */
    abstract toggleMouseSpeed: any;
    /**
     * Toggles mouse cursor visibility
     */
    abstract toggleMouseCursor: any;
    /**
     * Toggles between the big and regular mouse cursor size
     */
    abstract toggleMouseSize: any;
    /**
     * Toggles the system dark mode
     */
    abstract toggleDarkMode: any;
    /**
     * Opens a web view
     */
    abstract showWebView: any;
    /**
     * Saves selected text to variable selected_text
     * This can be later retrieved via (await btt.state.get('selected_text'))
     */
    abstract saveSelectedText: any;
    /**
     * Locks the screen
     */
    abstract lockScreen: any;
    /**
     * Logouts current user
     */
    abstract logout: any;
    /**
     * Sleeps computer display
     */
    abstract sleepDisplay: any;
    /**
     * Sleeps computer
     */
    abstract sleepComputer: any;
    /**
     * Restarts BetterTouchTool
     */
    abstract restart: any;
    /**
     * Shows system wide notification. Keep in mind that it's presence depends on the DnD state in the system.
     */
    abstract showNotification: any;
    /**
     * Quits BetterTouchTool
     */
    abstract quit: any;
}
