/**
 * Represents a BTT TouchBar Widget.
 */
import * as Types from '../types/types';
import { BttPayload } from '../types/types';
export declare class Widget {
    uuid: string;
    private default;
    private config;
    /**
     * Creates an instance representing BTT Widget
     * @param config
     * @param widgetConfig
     */
    constructor(config: Types.AppConfig, widgetConfig: Types.WidgetConfig);
    /**
     * Updates the current widget with given data
     * @param data
     */
    update(data?: Partial<BttPayload>): Promise<Types.CallResult>;
    /**
     * Refreshes current widget
     */
    refresh(): Promise<Types.CallResult>;
    /**
     * Triggers the widget
     */
    click(): Promise<Types.CallResult>;
    /**
     * Removes current widget
     */
    delete(): Promise<Types.CallResult>;
    /**
     * Allows to set the default callback programatically
     */
    setDefaultCallback(cb: Function): void;
    /**
     * Calls BTT with given payload using widget context
     * @TODO may be made reusable
     * @param mode
     * @param payload
     */
    private callBTTWithContext;
}
/**
 * Creates Widget class instance with given config
 */
export declare class FWidget {
    private config;
    /**
     * Takes an AppConfig as a constructor parameter
     * @param config
     */
    constructor(config: Types.AppConfig);
    /**
     * Returns a new Widget class instance and automatically passes the current btt instance config
     * @param config
     */
    get(config: Types.WidgetConfig): Widget;
    /**
     * Creates a new BetterTouchTool touchbar widget and returns its instance
     * @param options: Types.ITouchbarWidgetCreateConfig
     */
    create(options: Types.WidgetCreateConfig): Promise<Widget>;
}
